@@ -4,8 +4,8 @@ from typing import Any, Optional
 
 from testutil import AbstractOperatorTest, get_cr
 
-from fastflow.engine import TaskImpl, TaskInputInt, TaskOutput, TaskResult
-from fastflow.helpers import create_workflow_crd_object
+from fastflow import TaskImpl, TaskInputInt, TaskOutput, TaskResult
+from fastflow.kubernetes import create_workflow_crd_object
 from fastflow.models import WORKFLOWSTATUS, WorkflowCRD
 
 
